# Generated by ariadne-codegen
# Source: operations.graphql

from stigg._vendors.pydantic import Field

from .base_model import BaseModel
from .fragments import ProvisionSubscriptionFragment


class ProvisionSubscription(BaseModel):
    provision_subscription: "ProvisionSubscriptionProvisionSubscription" = Field(
        alias="provisionSubscription"
    )


class ProvisionSubscriptionProvisionSubscription(ProvisionSubscriptionFragment):
    pass


ProvisionSubscription.model_rebuild()
